# Contributor Guide

Thank you for your interest in improving this project. This project is
open-source under the MIT License and welcomes contributions in the form of bug
reports, feature requests, and pull requests.

Here is a list of important resources for contributors:

- [Source Code](https://github.com/dfm/jpu)
- [Documentation](https://github.com/dfm/jpu)
- [Issue Tracker](https://github.com/dfm/jpu/issues)

## How to report a bug

Report bugs on the [Issue Tracker](https://github.com/dfm/jpu/issues).

When filing an issue, make sure to answer these questions:

- Which operating system and Python version are you using?
- Which version of this project are you using?
- What did you do?
- What did you expect to see?
- What did you see instead?

The best way to get your bug fixed is to provide a test case, and/or steps to
reproduce the issue. In particular, please include a [Minimal, Reproducible
Example](https://stackoverflow.com/help/minimal-reproducible-example).
